@@ -122,7 +122,8 @@ def get_module_class(modulelist: Union[Type['Module'], Text, Sequence[Union[Text
         for modulearg in modulelist_it:
             if isinstance(modulearg, str):
                 modname, funcname = _split_module_string(modulearg, moduleloader)
-                module = _load_module_from_string(modname, modules_from_file)
+                files_allowed = modules_from_file or (moduleloader is not None and moduleloader.modules_from_file)
+                module = _load_module_from_string(modname, files_allowed)
                 handlerclass = _get_valid_module_class(module, funcname)
                 if handlerclass:
                     modules.append(handlerclass)
@@ -193,25 +194,23 @@ class _ModuleArgumentParser(argparse.ArgumentParser):
 
 
 class Module(metaclass=ClassPropertyMeta):
-    PARSER: Optional[_ModuleArgumentParser] = None
-    MODULES: Optional[List[Tuple[argparse.Action, Any]]] = None
+    _parser: Optional[_ModuleArgumentParser] = None
+    _modules: Optional[List[Tuple[argparse.Action, Any]]] = None
     CONFIG_PREFIX: Optional[Text] = None
 
     def __init__(self, args: Optional[Sequence[Text]] = None, namespace: Optional[argparse.Namespace] = None, **kwargs: Any) -> None:
-        if not self.PARSER:
-            self.prepare_module()
-        if self.PARSER:
-            self.args, _ = self.PARSER.parse_known_args(args, namespace)
+        self.args: argparse.Namespace
+        self.args, _ = self.PARSER.parse_known_args(args, namespace)
 
-            actions = {action.dest: action for action in self.PARSER._actions}  # type: ignore
-            for param_name, param_value in kwargs.items():
-                action = actions.get(param_name)
-                if not action:
-                    raise KeyError('keyword argument {} has no param'.format(param_name))
-                # check if it is an instance of the argument type, ignore mypy error because of false positive
-                if hasattr(action, 'type') and not isinstance(param_value, action.type):  # type: ignore
-                    raise ValueError('Value {} for parameter is not an instance of {}'.format(param_value, action.type))
-                setattr(self.args, param_name, param_value)
+        actions = {action.dest: action for action in self.PARSER._actions}  # type: ignore
+        for param_name, param_value in kwargs.items():
+            action = actions.get(param_name)
+            if not action:
+                raise KeyError('keyword argument {} has no param'.format(param_name))
+            # check if it is an instance of the argument type, ignore mypy error because of false positive
+            if hasattr(action, 'type') and not isinstance(param_value, action.type):  # type: ignore
+                raise ValueError('Value {} for parameter is not an instance of {}'.format(param_value, action.type))
+            setattr(self.args, param_name, param_value)
 
     @classmethod
     def add_module(cls, *args: Any, **kwargs: Any):
@@ -229,15 +228,20 @@ class Module(metaclass=ClassPropertyMeta):
     def parser_arguments(cls) -> None:
         pass
 
-    @classmethod
-    def prepare_module(cls) -> None:
-        cls.MODULES = []  # type: ignore
-        cls.PARSER = _ModuleArgumentParser(add_help=False, description=cls.__name__)  # type: ignore
-        cls.parser_arguments()
+    @classproperty
+    def MODULES(cls):
+        if '_modules' not in cls.__dict__:
+            cls._modules = []
+        return cls._modules
 
-    @classmethod
-    def get_modules(cls) -> Optional[List[Tuple[argparse.Action, Any]]]:
-        return cls.MODULES
+    @classproperty
+    def PARSER(cls) -> _ModuleArgumentParser:
+        if '_parser' not in cls.__dict__:
+            cls._parser = _ModuleArgumentParser(add_help=False, description=cls.__name__)  # type: ignore
+            cls.parser_arguments()
+        if not cls._parser:
+            raise ValueError('failed to create ModuleParser for {}'.format(cls))
+        return cls._parser
 
     @classproperty
     def config_section(cls) -> Text:  # pylint: disable=E0213
@@ -366,13 +370,11 @@ class ModuleParser(_ModuleArgumentParser):
                 if module is baseclass:
                     logging.error('module must not be baseclass!')
                     raise ModuleError(module, baseclass)
-                module.prepare_module()
-                if module.PARSER:
-                    moduleparsers.append(module.PARSER)
+                moduleparsers.append(module.PARSER)
 
                 try:
                     parsed_subargs, _ = module.PARSER.parse_known_args(args=args, namespace=namespace)
-                    moduleparsers.extend(self.get_sub_modules(parsed_subargs, args, namespace, module.get_modules()))
+                    moduleparsers.extend(self.get_sub_modules(parsed_subargs, args, namespace, module.MODULES))
                 except TypeError:
                     logging.exception("Unable to load modules")
         return moduleparsers
@@ -390,7 +392,6 @@ class ModuleParser(_ModuleArgumentParser):
                     raise ModuleError(module, self.baseclasses)
                 if module is self.baseclasses:
                     raise ModuleError(module, self.baseclasses)
-                module.prepare_module()
                 self.add_parser(module.PARSER)
                 parsed_sub_args = module.PARSER.parse_known_args(args=args, namespace=namespace)
                 submods = self.get_sub_modules(parsed_sub_args, args, namespace, parsed_args.modules, use_modules=True)
@@ -404,9 +405,7 @@ class ModuleParser(_ModuleArgumentParser):
 
         # load plugins
         for plugin in self._plugins:
-            plugin.prepare_module()
-            if plugin.PARSER:
-                self.add_parser(plugin.PARSER)
+            self.add_parser(plugin.PARSER)
 
         # initialize plugins
         for plugin in self._plugins:
@@ -416,9 +415,12 @@ class ModuleParser(_ModuleArgumentParser):
         parser = argparse.ArgumentParser(parents=list(self._module_parsers), **self.__kwargs)
         return parser
 
-    def parse_args(self, args: Optional[Sequence[Text]] = None, namespace: Optional[argparse.Namespace] = None) -> Optional[argparse.Namespace]:  # type: ignore
+    def parse_args(self, args: Optional[Sequence[Text]] = None, namespace: Optional[argparse.Namespace] = None) -> argparse.Namespace:  # type: ignore
         parser = self._create_parser(args=args, namespace=namespace)
-        return parser.parse_args(args, namespace)
+        args_namespace = parser.parse_args(args, namespace)
+        if not args_namespace:
+            return argparse.Namespace()
+        return args_namespace
 
     def parse_known_args(self, args: Optional[Sequence[Text]] = None, namespace: Optional[argparse.Namespace] = None) -> Tuple[argparse.Namespace, List[str]]:
         parser = self._create_parser(args=args, namespace=namespace)
